# gst-make

Command line tool for creating gstreamer plugin projects. Heavily based on the tools from `gstreamer-plugins-bad`.

## Getting Started

These tools consists of a collection of shell scripts for generating gstea

```
pip install gst-make
```

or

```
git clone https://github.com/ast/gst-make.git
```

### Prerequisites

You will need:

* python3
* gstreamer
* meson
* ninja

## TODO

* Some of the element templates are out of date.
* Probably a lot of other bugs.

## Built With

* [gstreamer](https://gstreamer.freedesktop.org/) - Best media framework in this galaxy.
* [meson](http://mesonbuild.com/) - The Meson Build system
* [ROME](https://rometools.github.io/rome/) - Used to generate RSS Feeds

## Contributing

Feedback and pull-requests are very welcome.

## Versioning

Still too early.

## Authors

* **Albin Stigö** - *Initial work* - [ast](https://github.com/ast)

See also the list of [contributors](https://github.com/your/project/contributors) who participated in this project.

## License

LGPL

## Acknowledgments

* gstreamer team

